@@ -40,8 +40,6 @@ def generateParser(name, LOG=None, parser=None):
     if parser is None:
         parser = cfgparse.ConfigParser()
     for filename in filenames:
-        if not filename.endswith('.ini'): 
-            continue
         parseModel(filename, parser,  LOG)
     return parser
 
